use {
	hyper::{
		Request,
		body::{
			Incoming,
		},
	},
	serde_json::{
		Value as Json,
		json,
	},
	skytable::{
		pool::ConnectionMgrTcp,
		query,
	},
	bb8::Pool,
	std::sync::Arc,
	crate::{
		double_split,
	},
};

type DBPool = Arc<Pool<ConnectionMgrTcp>>;


pub async fn api(req: Request<Incoming>, pool: DBPool) -> Json {
	let uri: &str = req.uri().path().as_ref();
	match &uri[7..uri.len()] {
		"/auth" => auth(req, pool.clone()).await,
		"/auth_get" => auth_get(req, pool.clone()).await,
		_ => json!({"error": true, "msg": "No endpoint"})
	}	
}

async fn auth(req: Request<Incoming>, _pool: DBPool) -> Json {
	let query = req.uri().query().or(Some("")).unwrap();
	let query = double_split(query.to_string(), "&", "=");
	let sess = std::string::String::from(query
		.get("session")
		.or(Some(&"".to_string()))
		.unwrap());
	match sess.as_str() {
		"" => json!({"error": true, "msg": "No session in url"}),
		_ => json!({
			"error": false,
			"link": format!("https://auth.bitheaven.ru/authorize?session={}", sess)
		})
	}
}

async fn auth_get(req: Request<Incoming>, pool: DBPool) -> Json {
	let mut con = pool.get().await.unwrap();

	let query = req.uri().query().or(Some("")).unwrap();
	let query = double_split(query.to_string(), "&", "=");
	let session = match query.get("session").is_none() {
		false => query.get("session").unwrap(),
		_ => ""
	};

	let res = con.query_parse::<(String, String)>(&query!(
		"SELECT login, uuid FROM bitauth.v0 WHERE session = ?",
		session
	)).await;
	let _ = con.query_parse::<()>(&query!(
		"DELETE FROM bitauth.v0 WHERE session = ?",
		session
	)).await;

	let (login, uuid) = match res.is_ok() {
		false => ("".to_owned(), "".to_owned()),
		_ => res.unwrap()
	};

	match login {
		"" => json!({"error": true, "msg": "Not auth yet"}),
		_ => json!({"error": false, "login": login, "uuid": uuid})
	}
}
